<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX Network Assistant</source>
        <translation>MX Assistent de Xarxa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>Status</source>
        <translation>Estat </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="76"/>
        <source>IP address</source>
        <translation>Adreça IP </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Hardware detected</source>
        <translation>Maquinari detectat </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <location filename="../mainwindow.ui" line="389"/>
        <location filename="../mainwindow.ui" line="502"/>
        <source>Re-scan</source>
        <translation>Re.explora</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="215"/>
        <source>Active interface</source>
        <translation>Interfície activa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="231"/>
        <source>WiFi status</source>
        <translation>Estat de la WiFi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Unblocks all soft/hard blocked wireless devices</source>
        <translation>Desbloqueja tots els dispositius sense fils </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="256"/>
        <source>Unblock WiFi Devices</source>
        <translation>Desbloqueja els dispositius WiFi </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>Linux drivers</source>
        <translation>Controladors Linux </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="300"/>
        <source>Associated Linux drivers</source>
        <translation>Controladors Linux associats </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>Load Driver</source>
        <translation>Carrega controlador </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Unload Driver</source>
        <translation>Descarrega controlador </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="409"/>
        <source>Block Driver</source>
        <translation>Bloca controlador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Windows drivers</source>
        <translation>Controladors Windows </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="434"/>
        <source>Available Windows drivers</source>
        <translation>Controladors Windows a l&apos;abast</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>Remove Driver</source>
        <translation>Elimina controlador </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <source>Add Driver</source>
        <translation>Afegeix controlador </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="520"/>
        <source>About NDISwrapper</source>
        <translation>Quant a NDISwrapper </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>Install NDISwrapper</source>
        <translation>Instal·la NDISwrapper </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
        <translation>Per poder usar els controladors de Windows primer cal instal·lar NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="559"/>
        <source>Uninstall NDISwrapper</source>
        <translation>Desinstal·la NDISwrapper </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="591"/>
        <source>Net diagnostics</source>
        <translation>Diagnòstics de xarxa </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="603"/>
        <source>Ping</source>
        <translation>Ping </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <location filename="../mainwindow.ui" line="726"/>
        <source>Target URL:</source>
        <translation>URL objectiu: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="619"/>
        <source>Packets</source>
        <translation>Paquets </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <location filename="../mainwindow.ui" line="781"/>
        <source>Start</source>
        <translation>Inici</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="678"/>
        <location filename="../mainwindow.ui" line="798"/>
        <source>Clear</source>
        <translation>Buida </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="692"/>
        <location filename="../mainwindow.ui" line="812"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="720"/>
        <source>Traceroute</source>
        <translation>Traceroute </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Hops</source>
        <translation>Salts </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="891"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="959"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="966"/>
        <source>Alt+C</source>
        <translation>Alt+C </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>IP address from router:</source>
        <translation>Adreça IP de l&apos;encaminador: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="88"/>
        <source>External IP address:</source>
        <translation>Adreça IP externa: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="196"/>
        <location filename="../mainwindow.cpp" line="210"/>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>&amp;Copy</source>
        <translation>&amp;Còpia </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <location filename="../mainwindow.cpp" line="213"/>
        <location filename="../mainwindow.cpp" line="227"/>
        <source>Copy &amp;All</source>
        <translation>Copi&amp;a Tot </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="201"/>
        <location filename="../mainwindow.cpp" line="215"/>
        <location filename="../mainwindow.cpp" line="229"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Traceroute not installed</source>
        <translation>Traceroute no està instal·lat </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Traceroute is not installed, do you want to install it now?</source>
        <translation>El traceroute no està instal·lat, voleu fer-ho ara? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>Traceroute hasn&apos;t been installed</source>
        <translation>El traceroute no s&apos;ha instal·lat </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
        <translation>El traceroute no es pot instal·lar. Això vol dir que esteu usant el CD autònom o no podeu accedir al dipòsit de programari. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
        <translation>El traceroute no està instal·lat i no s&apos;ha detectat cap connexió a internet, o sigui que no es pot instal·lar. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>No destination host</source>
        <translation>No hi ha amfitrió de destinació </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>Please fill in the destination host field</source>
        <translation>Si us plau, ompliu el camp d&apos;amfitrió de destinació </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <source>Loaded Drivers</source>
        <translation>Controladors carregats</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="449"/>
        <source>Unloaded Drivers</source>
        <translation>Controladors descarregats</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>Blocked Drivers</source>
        <translation>Controladors blocats</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>Blocked Broadcom Drivers</source>
        <translation>Controladors Broadcom blocats</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="894"/>
        <source>enabled</source>
        <translation>activat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="897"/>
        <source>disabled</source>
        <translation>desactivat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="900"/>
        <source>WiFi hardware switch is off</source>
        <translation>L&apos;interruptor de WiFi per maquinari està apagat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>Locate the Windows driver you want to add</source>
        <translation>Localitzeu el controlador de Windows que voleu afegir </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>Windows installation information file (*.inf)</source>
        <translation>Fitxer d&apos;informació d&apos;instal·lació Windows (*.inf) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="939"/>
        <source>*.sys file not found</source>
        <translation>No trobo el fitxer *.sys </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="939"/>
        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
        <translation>Els fitxers *.sys han d&apos;estar al mateix lloc que els *.inf. No trobo el fitxer %1 </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="948"/>
        <source>sys file reference not found</source>
        <translation>No trobo el fitxer de referència sys </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="948"/>
        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
        <translation>El fitxer sys per al controlador triat no es pot determinar després d&apos;analitzar el fitxer inf </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="967"/>
        <source>Ndiswrapper driver removed.</source>
        <translation>S&apos;ha eliminat el controlador ndiswrapper </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="975"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1012"/>
        <source>About %1</source>
        <translation>Quant a %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1013"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1014"/>
        <source>Program for troubleshooting and configuring network for MX Linux</source>
        <translation>Programa per a resolució de problemes i configuració de xarxa de MX Linux </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1016"/>
        <source>Copyright (c) MEPIS LLC and MX Linux</source>
        <translation>Copyright (c) MEPIS LLC i MX Linux </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1017"/>
        <source>%1 License</source>
        <translation>Llicència de %1</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>You must run this program as root.</source>
        <translation>Cal ser usuari principal per executar aquest programa. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="509"/>
        <source>Ndiswrapper is not installed</source>
        <translation>No s&apos;ha instal·lat NDISwrapper </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>driver installed</source>
        <translation>controlador instal·lat </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source> and in use by </source>
        <translation>i usat per </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>. Alternate driver: </source>
        <translation>. Controlador alternatiu: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="613"/>
        <source>Driver removed from blocklist</source>
        <translation>Controlador eliminat de la llista negra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="614"/>
        <source>Driver removed from blocklist.</source>
        <translation>Controlador eliminat de la llista negra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="620"/>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>Module blocked</source>
        <translation>Mòdul blocat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="786"/>
        <source>Installation successful</source>
        <translation>Instal·lació acabada amb èxit </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="789"/>
        <source>Error detected, could not compile ndiswrapper driver.</source>
        <translation>S&apos;ha detectat un error, no es pot compilar el ndiswrapper. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="792"/>
        <source>Error detected, could not install ndiswrapper.</source>
        <translation>S&apos;ha detectat un error, no es pot instal·lar ndiswrapper. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="804"/>
        <source>Error encountered while removing Ndiswrapper</source>
        <translation>S&apos;ha trobat un error en eliminar Ndiswrapper </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="855"/>
        <source>Unblock Driver</source>
        <translation>Contolador desblocat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>Block Driver</source>
        <translation>Bloca controlador</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="995"/>
        <source>Could not unlock devices.
WiFi device(s) might already be unlocked.</source>
        <translation>No es poden desbloquejar els dispositius.
El(s) dispositiu(s) WiFi potser ja estan desbloquejats. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="997"/>
        <source>WiFi devices unlocked.</source>
        <translation>Dispositius WiFi desbloquejats. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1040"/>
        <location filename="../mainwindow.cpp" line="1041"/>
        <source>Driver loaded successfully</source>
        <translation>Controlador carregat amb èxit </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1056"/>
        <location filename="../mainwindow.cpp" line="1057"/>
        <source>Driver unloaded successfully</source>
        <translation>Controlador descarregat amb èxit </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="638"/>
        <source>Could not load </source>
        <translation>No es pot carregar </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="669"/>
        <source>Could not unload </source>
        <translation>No es pot descarregar </translation>
    </message>
</context>
</TS>
